@@ -613,8 +613,8 @@ appropriate keymap if a key is requested. Format:
        1 font-lock-comment-face t)))
     "Additional expressions to highlight in HTML mode.")
 
-(put 'html-mode 'font-lock-defaults '(html-font-lock-keywords))
-(put 'html3-mode 'font-lock-defaults '(html-font-lock-keywords))
+(put 'html-mode 'font-lock-defaults '(html-font-lock-keywords nil t))
+(put 'html3-mode 'font-lock-defaults '(html-font-lock-keywords nil t))
 
 ;;}}}
 
@@ -781,6 +781,8 @@ get those characters to appear literally in the output."
 		   (buffer-file-name
 		    (current-buffer))]
 		  ["View in W3" w3-preview-this-buffer t]
+		  ["View in kfm" sgml-html-kfm-file
+		   (buffer-file-name (current-buffer))]
 		  "---"
 		  ["HTML-Quote Region" html-quote-region t]
 		  "---")
@@ -792,6 +794,12 @@ get those characters to appear literally in the output."
   (highlight-headers-follow-url-netscape
    (concat "file:" (buffer-file-name (current-buffer)))))
 
+(defun sgml-html-kfm-file ()
+  "Preview the file for the current buffer in kfm."
+  (interactive)
+  (highlight-headers-follow-url-kfm
+   (concat "file:" (buffer-file-name (current-buffer)))))
+
 (define-derived-mode html3-mode html-mode "HTML3"
   (setq sgml-declaration             (expand-file-name "html3.decl"
 						       sgml-data-directory)
